#
# spec file for package SAPHanaSR-ScaleOut
#
# Copyright (c) 2016      SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2017-2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

Name:           SAPHanaSR-ScaleOut
License:        GPL-2.0
Group:          Productivity/Clustering/HA
AutoReqProv:    on
Summary:        Resource agents to control the HANA database in system replication setup
Version:        0.184.1
Release:        150000.33.1
Url:            http://scn.sap.com/community/hana-in-memory/blog/2014/04/04/fail-safe-operation-of-sap-hana-suse-extends-its-high-availability-solution
Source0:        SAPHanaSR-ScaleOut-%{version}.tar.bz2

BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

Requires:       pacemaker > 1.1.1
Requires:       resource-agents
Requires:       perl
Requires:       python3
Requires:       /usr/bin/xmllint
Conflicts:      SAPHanaSR

%package doc
Summary:        Setup-Guide for SAPHanaSR
Group:          Productivity/Clustering/HA
Conflicts:      SAPHanaSR-doc

%description
The resource agents SAPHanaController and SAPHanaTopology are responsible for
controlling a SAP HANA Database which is running in system replication (SR)
configuration.

For SAP HANA Databases in System Replication only the described or referenced
scenarios in the SAPHanaSR-ScaleOut(7) man page included in this package are
supported.
For any scenario not matching the scenarios named or referenced in this man
page please contact SUSE at SAP LinuxLab (sap-lab@suse.de).

The following SCN blog gives a first overwiew about running SAP HANA in system
replication with our resource agents:
http://scn.sap.com/community/hana-in-memory/blog/2014/04/04/fail-safe-operation-of-sap-hana-suse-extends-its-high-availability-solution



Authors:
--------
    Fabian Herschel

%description doc
This sub package points to the Setup-Guide for getting SAP HANA system replication under cluster control.

%prep
tar xf %{S:0}

%build
gzip man/*

%install
mkdir -p %{buildroot}/usr/sbin
mkdir -p %{buildroot}%{_docdir}/%{name}
mkdir -p %{buildroot}/usr/share/%{name}/tests
mkdir -p %{buildroot}/usr/share/%{name}/samples
mkdir -p %{buildroot}%{_mandir}/man7
mkdir -p %{buildroot}%{_mandir}/man8
mkdir -p %{buildroot}/usr/lib/ocf/resource.d/suse/

# resource agents
install -m 0755 ra/* %{buildroot}/usr/lib/ocf/resource.d/suse/

# documentation
install -m 0444 doc/* %{buildroot}/%{_docdir}/%{name}

# manuals
install -m 0444 man/*.7.gz %{buildroot}/usr/share/man/man7
install -m 0444 man/*.8.gz %{buildroot}/usr/share/man/man8

# aux. scripts
#    SAPHanaSR-showAttr, SAPHanaSR-monitor
install -m 0555 bin/* %{buildroot}/usr/sbin
install -m 0555 test/SAPHanaSR-replay-archive %{buildroot}/usr/sbin
install -m 0555 test/SAPHanaSR-filter %{buildroot}/usr/sbin
install -m 0555 test/SAPHanaSR-hookHelper %{buildroot}/usr/sbin
install -m 0555 test/SAPHanaSR-manageProvider %{buildroot}/usr/sbin
install -m 0555 test/SAPHanaSR-show-hadr-runtimes %{buildroot}/usr/sbin
install -m 0555 test/SAPHanaSR-show-hadr-log-coincidence %{buildroot}/usr/sbin
install -Dm 0444 test/SAPHanaSRTools.pm %{buildroot}/usr/lib/%{name}/SAPHanaSRTools.pm

# sample configurations
install -m 0444 crmconfig/* %{buildroot}/usr/share/%{name}/samples

# sample scripts
install -m 0755 test/SAPHanaSR-call-monitor %{buildroot}/usr/share/%{name}/samples

# HAWK components
install -Dm 0444 wizard/templates/SAPHanaSR-ScaleOut.xml %{buildroot}/srv/www/hawk/config/wizard/templates/SAPHanaSR-ScaleOut.xml
install -Dm 0444 wizard/workflows/90-SAPHanaSR-ScaleOut.xml  %{buildroot}/srv/www/hawk/config/wizard/workflows/90-SAPHanaSR-ScaleOut.xml

# HANA hooks
install -m 0644 srHook/SAPHanaSR.py %{buildroot}/usr/share/%{name}/
install -m 0644 srHook/SAPHanaSrMultiTarget.py %{buildroot}/usr/share/%{name}/
install -m 0644 srHook/susTkOver.py %{buildroot}/usr/share/%{name}/
install -m 0644 srHook/susChkSrv.py %{buildroot}/usr/share/%{name}/
install -m 0444 srHook/global.ini %{buildroot}/usr/share/%{name}/samples
install -m 0444 srHook/global.ini_TakeoverBlocker %{buildroot}/usr/share/%{name}/samples
install -m 0444 srHook/sudoers %{buildroot}/usr/share/%{name}/samples

%files
%defattr(-,root,root)
%dir /usr/lib/ocf
%dir /usr/lib/ocf/resource.d
%dir /usr/lib/ocf/resource.d/suse
/usr/lib/ocf/resource.d/suse/SAPHanaController
/usr/lib/ocf/resource.d/suse/SAPHanaTopology
/usr/share/%{name}
/usr/lib/%{name}
/usr/sbin/SAPHanaSR-monitor
/usr/sbin/SAPHanaSR-showAttr
/usr/sbin/SAPHanaSR-manageAttr
/usr/sbin/SAPHanaSR-replay-archive
/usr/sbin/SAPHanaSR-filter
/usr/sbin/SAPHanaSR-hookHelper
/usr/sbin/SAPHanaSR-manageProvider
/usr/sbin/SAPHanaSR-show-hadr-runtimes
/usr/sbin/SAPHanaSR-show-hadr-log-coincidence
%dir /srv/www/hawk
%dir /srv/www/hawk/config
%dir /srv/www/hawk/config/wizard
%dir /srv/www/hawk/config/wizard/templates
%dir /srv/www/hawk/config/wizard/workflows
/srv/www/hawk/config/wizard/templates/SAPHanaSR-ScaleOut.xml
/srv/www/hawk/config/wizard/workflows/90-SAPHanaSR-ScaleOut.xml
%dir %{_docdir}/%{name}
%doc %{_docdir}/%{name}/README
%doc %{_docdir}/%{name}/LICENSE
%doc %{_mandir}/man7/*
%doc %{_mandir}/man8/*

%files doc
%defattr(-,root,root)
%doc %{_docdir}/%{name}/SAPHanaSR-Setup-Guide.pdf

%changelog
* Tue Nov 29 2022 abriel@suse.com
- Version bump to 0.184.1
  * add new HA/DR provider hook susChkSrv supporting a fast-dying
    indexserver
    (jsc#PED-1241, jsc#PED-1240)
  * add new HA/DR provider hook susTkOver for blocking manual
    takeovers
    (jsc#SLE-16347)
  * add improvements from SAP to the RA scripts regarding the
    handling of the SAP tools 'HDB version', 'HDBSettings.sh' and
    'pycd' and the SAPHana log filter handling
    (jsc#PED-1739)
  * fix SAPHanaSR-replay-archive to handle hb_report archives again
    (bsc#1198897)
  * fix for SAPHanaSR-monitor reporting "LPA status of one node is
    missing"
    (bsc#1192963, bsc#1203973)
  * add lost-nameserver-slave handling to SAPHanaTopology, to avoid
    toggeling SAPHanaController resource, if all nameserver-masters
    got lost.
    SAPHanaController keeps started, if WAITING4NODES event needs
    to be processed. This only keeps the resource "started".
    The SAP HANA instance will only be started, if enough nodes are
    available to fulfill the needs of the SAP HANA landscape.
  * add new tool SAPHanaSR-manageProvider to show, add and delete
    HA/DR provider sections in the global.ini of SAP HANA.
  * changes to the demote_clone function of the resource agent:
    if the role is '*:shtdown:shtdown:shtdown' (topology agent run
    into timeouts) the function fail with rc=1, to get the managed
    resource stopped
    changes to the stop_clone function of the topology agent:
    call landscapeHostConfiguration.py and set the roles as they
    were reported. If the command timed out, set the role to
    '*:shtdown:shtdown:shtdown' and return 1 to get the node
    fenced.
    The used timeout for the landscapeHostConfiguration.py call can
    be configured by the cluster action timeout, if needed. It will
    be 50%% of the action timeout or the minimum of 300s.
    (bsc#1198127)
  * SAPHanaSRTools.pm: shows terminate node attribute too
  * change SAPHanaSR-manageAttr to support the different behaviour
    of 'crmadmin -qD' in different pacemaker versions
    (bsc#1200969)
  * fix HANA_CALL function to support MCOS environments again
    (bsc#1198780)
  * correct the order constraint in man page
    ocf_suse_SAPHanaTopology.7
    (bsc#1197239)
* Mon Jan 10 2022 abriel@suse.com
- change version to 0.181.0
- Add systemd support for the resource agent to interact with the
  new SAP unit files for sapstartsrv.
  As the new version of the SAP Startup Framework will use systemd
  unit files to control the sapstartsrv process instead of the
  previous used SysV init script, we need to adapt the handling of
  sapstartsrv inside the resource agents to support both ways.
  (bsc#1189532, bsc#1189533)
- add dedicated logging of HANA_CALL problems. So it will be now
  possible to identify, if the called hana command or the needed
  su command throws the error and for further hints we log the
  stderr output.
  Additional it is possible to get regular log messages for the
  used commands, their return code and their stderr output by
  enabling the 'debug' mode of the resource agents.
  (bsc#1182774)
- add switch 'cib_access' to the SAPHanaSrMultiTarget hook to give
  control over the hook runtime.
  Default is 'all-on' which means there are 3 cib calls performed
  inside the hook script.
  Changing the value of 'cib_access' inside the global.ini file to
  'site-on' to perform the absolute minimum cib calls (only one)
  (bsc#1189540)
* Mon Aug  2 2021 abriel@suse.com
- change version to 0.180.1
- Multi-target SAP HANA Scale-out replication support.
  Extent the SAP HANA ressource agents from single replication
  automation to multi replication automation, which means
  adding multi-target support (srHook - SAPHanaSrMultiTarget.py)
  /usr/sbin/SAPHanaSR-manageAttr - Add a helper tool to support the
  customer during the update from a single replication automation
  to multi replication automation.
  (jsc#SLE-17452, jsc#SLE-20081)
- The resource start and stop timeout is now configurable by
  increasing the timeout for the action 'start' and/or 'stop' in
  the cluster. We will use 95%% of this action timeouts to calculate
  the new resource start and stop timeout for the 'WaitforStarted'
  and 'WaitforStopped' functions. If the new, calculated timeout
  value is less than '3600', it will be set to '3600', so that we
  do not decrease this timeout by accident in currently running
  clusters
  (bsc#1182545)
- improve handling of return codes in saphana_stopSystem and
  saphana_stop function.
  (bsc#1182115)
- If the cluster is down during a SR change event, these events
  need special care. They need to pick-up separately to not get
  lost.
- integrate man pages back to the base package SAPHanaSR-ScaleOut.
  The doc package SAPHanaSR-ScaleOut-doc will still exists, but
  only contain the file 'SAPHanaSR-Setup-Guide.pdf'
- During a SR takeover there may be a small time frame where the
  srHook gets a state change from the API with an empty site name.
  This results in a mis-configuration of the cluster. So log the
  occurrence of an empty site name, but do not generate bad
  formatted cluster attribute name.
  (analog to ScaleUp - bsc#1173581)
- add SAPHanaSR-call-monitor
- handle 'leftover instances'
  if HANA is configured to have only one master name server, but
  no additional master name server candidates, there may be the
  situation, where the master name serve died and so the landscape
  has no active name server anymore.
  But there are other instances running with active communication
  channels. To prevent data corruption or operations on outdated
  data, we identify and stop these 'leftover' instances.
- manual page updates:
  SAPHanaSR-ScaleOut.7 (bsc#1144442)
  SAPHanaSR-showAttr.8 (bsc#1144312)
  and others
* Thu Mar  4 2021 abriel@suse.com
- change version to 0.164.2
- The resource start and stop timeout is now configurable by
  increasing the timeout for the action 'start' and/or 'stop'.
  We will use 95%% of this action timeouts to calculate the new
  resource start and stop timeout for the 'WaitforStarted' and
  'WaitforStopped' functions. If the new, calculated timeout value
  is less than '3600', it will be set to '3600', so that we do not
  decrease this timeout by accident
  (bsc#1182545)
- add return codes for saphana_stop and saphana_StopSystem
  (bsc#1182115)
- man page SAPhanaSR-ScaleOut minor mistakes
  (bsc#1144442)
* Wed Nov  4 2020 abriel@suse.com
- change version to 0.164.1
- adapt man page SAPHanaSR-showAttr(8) and the README
  (bsc#1144729)
* Mon Sep 21 2020 abriel@suse.com
- PROMOTED/PROMOTED Fix - The PROMOTED/PROMOTED values happened
  after the main tenance procedure and the refresh of the resource
  did not fixed that
  (bsc#1176330)
- Improved SCORING and logging
  Score of secondary in takeover phase increased from 122 to 145 to
  avoid promotion of former primary masternameserver candidates
  (bsc#1174610)
- Fixed typos and improved descriptions in comments
- Change default timeouts and intervals to match the official
  recommendations
* Thu May 14 2020 abriel@suse.com
- let the SAPHanaSR-ScaleOut-doc package conflict with the
  SAPHanaSR-doc package
  (bsc#1157685)
* Mon Nov 11 2019 abriel@suse.com
- change version to 0.164.0
- restart sapstartsrv service on master nameserver node
  (bsc#1156150)
- Use a fall-back scoring for the master nameserver nodes, if the
  current roles of the node(s) got lost.
  (bsc#1156067)
- clean up package, add checks, correct typos
* Wed Sep 12 2018 clanig@suse.de
- Version 0.163.2
- Fix bsc#1098979: SAPHanaSR-ScaleOut SAPHanaTopology and
  SAPHanaController allowing virtual host names
* Tue Jun 26 2018 imanyugin@suse.com
- Version 0.163.1
* Tue May  8 2018 imanyugin@suse.com
- Fix bsc#1092331: SAPHanaSR: SAPHanaSR-showAttr fails to open an archived cib file
- Fix bsc#1091988:SAPHanaSR-ScaleOut SAPHanaSR-monitor depends on package not existing in SLES
- SAPHanaSR-showAttr, SAPHanaSR-monitor moved to /usr/sbin to match the file layout in SAPHanaSR-ScaleUp
* Tue Apr  3 2018 imanyugin@suse.com
- Version 0.163.0
- Fix bsc#1045603: Update man pages
- Fix bsc#1045536: SAPHanaSR-ScaleOut missing update to use SLES python
- Fix bsc#1086545: minor typos in package description and man pages
* Thu Jul 14 2016 imanyugin@suse.com
- Version 0.161.1
- Added a package conflict for SAPHanaSR, bsc#989162
- Restructure package and the .spec file
* Mon Jun 13 2016 imanyugin@suse.com
- Initial technical preview release. fate#318793
